@@ -365,7 +365,16 @@ impl AxoUpdater {
     /// Returns a normalized version of install_prefix_root, for comparison
     fn install_prefix_root_normalized(&self) -> AxoupdateResult<Utf8PathBuf> {
         let raw_root = self.install_prefix_root()?;
-        let normalized = Utf8PathBuf::from_path_buf(raw_root.canonicalize()?)
+        // The canonicalize path could fail if the path doesn't exist anymore;
+        // catch that specific error here and return the original path.
+        // (We want to leave the UTF8 conversion to the next step so we handle
+        // those errors separately.)
+        let canonicalized = if let Ok(path) = raw_root.canonicalize() {
+            path
+        } else {
+            raw_root.into_std_path_buf()
+        };
+        let normalized = Utf8PathBuf::from_path_buf(canonicalized)
             .map_err(|path| AxoupdateError::CaminoConversionFailed { path })?;
         Ok(normalized)
     }
@@ -483,6 +492,10 @@ impl AxoUpdater {
         };
         let mut command = Cmd::new(path, "execute installer");
         if cfg!(windows) {
+            // don't fall over on default security-policy windows machines
+            // which require opt-in to execing powershell scripts.
+            // This doesn't bypass proper organization-set policies.
+            command.arg("-ExecutionPolicy").arg("ByPass");
             command.arg(&installer_path);
         }
         if self.print_installer_stdout {
@@ -500,6 +513,13 @@ impl AxoUpdater {
         // Forces the generated installer to install to exactly this path,
         // regardless of how it's configured to install.
         command.env("CARGO_DIST_FORCE_INSTALL_DIR", &install_prefix);
+
+        // Also set the app-specific name for this; in the future, the
+        // CARGO_DIST_ version may be removed.
+        let app_name = self.name.clone().unwrap_or_default();
+        let app_specific_env_var = app_name.to_ascii_uppercase().replace('-', "_") + "_INSTALL_DIR";
+        command.env(app_specific_env_var, &install_prefix);
+
         let result = command.output();
 
         let failed;
